SET CURRENT SQLID='RTESCHMA';
 
DROP INDEX IXPART;
DROP INDEX IXNONPRT;
DROP TABLE SIMPTBL;
DROP TABLE PARTDES;
DROP TABLE PARTQTY;
DROP TABLE PARTLOC;
DROP TABLESPACE TESTDB.TBSPSIMP;
DROP TABLESPACE TESTDB.TBSPPART;
DROP TABLESPACE TESTDB.TBSPSEG1;
DROP TABLESPACE TESTDB.TBSPSEG2;
DROP TABLESPACE TESTDB.TBSPSEG3;
DROP TABLESPACE TESTDB.TBSPLRG;
DROP TABLESPACE TESTDB.PHOTOLTS;
DROP TABLESPACE TESTDB.RESUMLTS;
COMMIT;
 
DROP DATABASE TESTDB;
COMMIT;
 
DROP STOGROUP STOGRP01;
COMMIT;
 
CREATE STOGROUP STOGRP01
                 VOLUMES (XTRA01,SCR03)
                 VCAT TESTCAT;
 
CREATE DATABASE TESTDB
                 CCSID EBCDIC
                 BUFFERPOOL BP0
                 STOGROUP STOGRP01;
 
-- this is the primary tablespace for testing
CREATE TABLESPACE TS02 IN TESTDB
        USING STOGROUP STOGRP01
              PRIQTY 20
              SECQTY 8
              ERASE NO
        FREEPAGE 0
        PCTFREE 5
        SEGSIZE 4
        BUFFERPOOL BP2
        LOCKSIZE ANY
              LOCKMAX SYSTEM
        LOCKPART NO
        CLOSE NO
        COMPRESS NO
        CCSID EBCDIC;
 
CREATE TABLESPACE TBSPSIMP IN TESTDB
                   CCSID EBCDIC
                   LOCKSIZE ANY
                   CLOSE NO;
 
CREATE TABLESPACE TBSPPART IN TESTDB
                   CCSID EBCDIC
                   FREEPAGE 1
                   NUMPARTS 4 (PART 1 USING STOGROUP STOGRP01,
                               PART 2 USING STOGROUP STOGRP01,
                               PART 3 USING STOGROUP STOGRP01,
                               PART 4 USING STOGROUP STOGRP01)
                   LOCKSIZE ANY
                   CLOSE NO;
 
CREATE TABLESPACE TBSPSEG1 IN TESTDB
                   CCSID EBCDIC
                   SEGSIZE  60
                   LOCKSIZE ROW
                   CLOSE NO;
 
CREATE TABLESPACE TBSPSEG2 IN TESTDB
        USING STOGROUP STOGRP01
              PRIQTY 20
              SECQTY 8
              ERASE NO
        FREEPAGE 0
        PCTFREE 5
        SEGSIZE 4
        BUFFERPOOL BP2
        LOCKSIZE ANY
        LOCKMAX SYSTEM
        LOCKPART NO
        CLOSE NO
        COMPRESS NO
        CCSID EBCDIC;
 
CREATE TABLESPACE TBSPSEG3 IN TESTDB
        USING STOGROUP STOGRP01
              PRIQTY 544
              SECQTY 64
              ERASE NO
        FREEPAGE 0
        PCTFREE 5
        SEGSIZE 64
        BUFFERPOOL BP22
        LOCKSIZE ANY
              LOCKMAX SYSTEM
        LOCKPART NO
        CLOSE NO
        COMPRESS NO
        CCSID EBCDIC;
 
CREATE LARGE TABLESPACE TBSPLRG
IN TESTDB
USING STOGROUP STOGRP01
       NUMPARTS 82
          (PART 80
            COMPRESS YES,
           PART 81
            COMPRESS YES,
           PART 82
            COMPRESS YES)
          LOCKSIZE PAGE
          BUFFERPOOL BP1
          CLOSE NO ;
 
CREATE LOB TABLESPACE PHOTOLTS
IN TESTDB
USING STOGROUP STOGRP01
PRIQTY 3200
SECQTY 1600
LOCKSIZE LOB
BUFFERPOOL BP16K0
LOG NO
CLOSE NO;
 
CREATE LOB TABLESPACE RESUMLTS
IN TESTDB
USING STOGROUP STOGRP01
PRIQTY 3200
SECQTY 1600
LOCKSIZE LOB
BUFFERPOOL BP16K0
LOG NO
CLOSE NO;
 
-- now create the tables for each tablespace
 
CREATE TABLE SIMPTBL
    (INVOICE INTEGER NOT NULL,
     PRODCODE INTEGER NOT NULL,
     PRODDESC     VARCHAR(40),
     PRODCOST     DECIMAL(5,2) )
   IN TESTDB.TBSPSIMP;
 
CREATE TABLE TBPART01
    (PF11            CHAR(4) NOT NULL,
     F12               DECIMAL(15,0) DEFAULT NULL,
     P2                 TIMESTAMP NOT NULL WITH DEFAULT,
     P13                INTEGER NOT NULL,
     CHARCHCK         CHAR(8) CHECK (CHARCHCK <> 'CHRCHCK'),
     VARCHAR20WD      VARCHAR(20) WITH DEFAULT 'VARCHAR20DEFAULT',
     DEFUSER          CHAR(8) WITH DEFAULT USER,
     DEFSQLID         CHAR(8) WITH DEFAULT CURRENT SQLID,
     DEFNULL          CHAR(8) WITH DEFAULT NULL)
  IN TESTDB.TBSPPART
  PARTITION BY (PF11, P2, P13)
      (PART 1 VALUES ('ffff'),  PART 2 VALUES ('llll'), PART 3 VALUES ('rrrr'), PART 4 VALUES ('zzzz') )
   AUDIT NONE
   DATA CAPTURE NONE
   CCSID EBCDIC;
 
CREATE INDEX IXPART
                    ON TBPART01 (PF11, P2, P13);
 
CREATE INDEX IXNONPRT
                    ON TBPART01 (PF11, P2, CHARCHCK ASC)
                    USING STOGROUP STOGRP01;
 
CREATE TABLE PARTDES
    (PN_PREFIX CHAR(3) NOT NULL,
     PN_SUFFIX CHAR(2) NOT NULL,
     PN_BASE          CHAR(5) NOT NULL,
     PARTDESC       VARCHAR(40) )
   IN TESTDB.TBSPSEG1;
 
CREATE TABLE PARTQTY
    (PN_PREFIX CHAR(3) NOT NULL,
     PN_SUFFIX CHAR(2) NOT NULL,
     PN_BASE          CHAR(5) NOT NULL,
     QUANTITY         INTEGER )
   IN TESTDB.TBSPSEG2;
 
CREATE TABLE PARTLOC
    (PN_PREFIX CHAR(3) NOT NULL,
     PN_SUFFIX CHAR(2) NOT NULL,
     PN_BASE          CHAR(5) NOT NULL,
     WAREHOUSE   CHAR(10),
     WH_AISLE         CHAR(2),
     WH_BIN CHAR(3) )
   IN TESTDB.TBSPSEG3;
